﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Collections.ObjectModel;

using MindFusion.Charting;
using MindFusion.Charting.Components;
using MindFusion.Drawing;

using Color = System.Drawing.Color;


namespace Interactivity
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			
			// BarChart
			barChart.Series = GetSeriesCollection();
			barChart.Dock = DockStyle.Fill;
			barChart.Title = "Bar Chart";
			barChart.BackColor = Color.WhiteSmoke;

			barChart.AllowZoom = true;
			barChart.AllowPan = true;
			barChart.AllowMoveLegend = true;

			barChart.XAxis.Title = "";
			barChart.XAxis.MinValue = 0;
			barChart.XAxis.MaxValue = 3;
			barChart.YAxis.Title = "";
			barChart.YAxis.MinValue = 0;
			barChart.YAxis.MaxValue = 100;

			barChart.ShowLegend = true;
			barChart.LegendHorizontalAlignment = LayoutAlignment.Near;
			barChart.LegendVerticalAlignment = LayoutAlignment.Near;

			barChart.Theme = new Theme();
			barChart.Theme.CommonSeriesFills = GetBarFills();
			barChart.Theme.CommonSeriesStrokes = GetBarFills();
			barChart.Theme.LegendBackground = new SolidBrush(Color.FromArgb(200, 200, 200));
			barChart.Theme.LegendBorderStroke = new SolidBrush(Color.FromArgb(180, 180, 180));
			barChart.Theme.HighlightStroke = new SolidBrush(Color.DarkRed);
			barChart.Theme.HighlightStrokeThickness = 3;
			barChart.Theme.DataLabelsBrush = new SolidBrush(Color.White);
			barChart.GridType = GridType.Horizontal;
			barChart.Theme.GridLineStyle = System.Drawing.Drawing2D.DashStyle.Dash;
			barChart.Theme.GridColor1 = barChart.Theme.GridColor2 = Color.FromArgb(245, 245, 245);

			// PieChart
			pieChart.Series = new PieSeries(
				new double[] { 20, 60, 40, 55 },
				new string[] { "January", "February", "March", "April" },
				new string[] { "January", "February", "March", "April" }) { Title = "Pie Series"};
			pieChart.Dock = DockStyle.Fill;
			pieChart.Title = "Pie Chart";

			pieChart.AllowZoom = true;
			pieChart.AllowRotate = true;

			pieChart.ShowLegend = false;
			pieChart.ShowDataLabels = LabelKinds.OuterLabel;

			pieChart.Theme = new Theme();
			pieChart.Theme.SeriesFills = GetPieFills();
			pieChart.Theme.UniformSeriesStroke = new SolidBrush(Color.FromArgb(240, 240, 240));
			pieChart.Theme.SeriesStrokeThicknesses = new List<List<double>>() { new List<double>() { 15 } };
			pieChart.Theme.HighlightStroke = new SolidBrush(Color.White);
			pieChart.Theme.HighlightStrokeThickness = 10;
			pieChart.Theme.DataLabelsFontSize = 14;
		}

		private ObservableCollection<Series> GetSeriesCollection()
		{
			ObservableCollection<Series> collection = new ObservableCollection<Series>();
			for (int i = 0; i < 3; i++)
			{
				if (i == 0)
				{
					collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
						new double[] { 20, 60, 40, 55 },
						new string[] { "January", "February", "March", "April" }) { Title = "Series 1" });
				}
				if (i == 1)
				{
					collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
					   new double[] { 30, 70, 65, 19 },
					   new string[] { "May", "June", "July", "August" }) { Title = "Series 2" });
				}
				if (i == 2)
				{
					collection.Add(new Series2D(new double[] { 0, 1, 2, 3 },
					   new double[] { 22, 44, 33, 66 },
					   new string[] { "September", "October", "November", "December" }) { Title = "Series 3" });
				}
			}
			return collection;
		}

		private List<Brush> GetBarFills()
		{
			var fills = new List<Brush>();

			fills.Add(new SolidBrush(Color.FromArgb(102, 154, 204)));
			fills.Add(new SolidBrush(Color.FromArgb(0, 52, 102)));
			fills.Add(new SolidBrush(Color.FromArgb(206, 0, 0)));

			return fills;
		}

		private List<List<Brush>> GetPieFills()
		{
			var fills = new List<List<Brush>>();

			fills.Add(new List<Brush>() { 
				new SolidBrush(Color.FromArgb(102, 154, 204)),
				new SolidBrush(Color.FromArgb(192, 192, 192)),
				new SolidBrush(Color.FromArgb(0, 52, 102)),
				new SolidBrush(Color.FromArgb(206, 0, 0)),
			});

			return fills;
		}

		private void button1_Click(object sender, EventArgs e)
		{
			barChart.ResetZoom();
		}
	}
}